@@ -261,8 +261,16 @@ class PgnImport():
                     else:
                         variant = 0
 
-                    white = tags["White"] if "White" in tags else ""
-                    black = tags["Black"] if "Black" in tags else ""
+                    if basename == "eco.pgn":
+                        white = tags["Opening"] if "Opening" in tags else ""
+                        black = tags["Variation"] if "Variation" in tags else ""
+                    else:
+                        white = tags["White"] if "White" in tags else ""
+                        if white == "":
+                            white = "?"
+                        black = tags["Black"] if "Black" in tags else ""
+                        if black == "":
+                            black = "?"
 
                     event_id = get_id(tags["Event"] if "Event" in tags else "", event, EVENT)
 
@@ -280,7 +288,7 @@ class PgnImport():
                             game_year, game_month, game_day = int(game_date[:4]), None, None
                         else:
                             game_year, game_month, game_day = None, None, None
-                    except:
+                    except (ValueError, IndexError):
                         game_year, game_month, game_day = None, None, None
 
                     game_round = tags['Round'] if "Round" in tags else ""
@@ -292,9 +300,11 @@ class PgnImport():
                     if result in pgn2Const:
                         result = pgn2Const[result]
                     else:
-                        if basename != "eco.pgn":
+                        if basename == "eco.pgn":
+                            result = RUNNING
+                        else:
                             print("Invalid Result tag in game #%s: %s" % (i + 1, result))
-                        continue
+                            continue
 
                     white_elo = tags['WhiteElo'] if "WhiteElo" in tags else "0"
                     white_elo = int(white_elo) if white_elo and white_elo.isdigit() else 0
@@ -481,9 +491,9 @@ def read_games(handle, handle_json=None):
                             continue
                     else:
                         continue
-                except:
+                except ValueError:
                     continue
-            except:
+            except ValueError:
                 continue
         return
 
