@@ -54,9 +54,9 @@ anare = re.compile("""
                              #   Mat1 is used by gnuchess to specify mate in one.
                              #   otherwise we should support a signed float
     \s+                      #
-    [\d\.]+                  # The time used in seconds
+    ([\d\.]+)                # The time used in centi-seconds
     \s+                      #
-    [\d\.]+                  # Number of nodes visited
+    ([\d\.]+)                # Number of nodes visited
     \s+                      #
     (.+)                     # The Principal-Variation. With or without move numbers
     \s*                      #
@@ -190,7 +190,7 @@ class CECPEngine(ProtocolEngine):
             except asyncio.TimeoutError:
                 log.warning("Got timeout error", extra={"task": self.defname})
                 raise PlayerIsDead
-            except:
+            except Exception:
                 log.warning("Unknown error", extra={"task": self.defname})
                 raise PlayerIsDead
             else:
@@ -280,9 +280,16 @@ class CECPEngine(ProtocolEngine):
 
     # Send the player move updates
 
-    def setBoard(self, board):
-        self.setBoardList([board], [])
-        self.__sendAnalyze(self.mode == INVERSE_ANALYZING)
+    def setBoard(self, board, search=True):
+        def coro():
+            if self.engineIsAnalyzing:
+                self.__stop_analyze()
+                yield from asyncio.sleep(0.1)
+
+            self.setBoardList([board], [])
+            if search:
+                self.__sendAnalyze(self.mode == INVERSE_ANALYZING)
+        asyncio.async(coro())
 
     def putMove(self, board1, move, board2):
         """ Sends the engine the last move made (for spectator engines).
@@ -290,9 +297,15 @@ class CECPEngine(ProtocolEngine):
             @param move: The last move made
             @param board2: The board before the last move was made
         """
+        def coro():
+            if self.engineIsAnalyzing:
+                self.__stop_analyze()
+                yield from asyncio.sleep(0.1)
 
-        self.setBoardList([board1], [])
-        self.__sendAnalyze(self.mode == INVERSE_ANALYZING)
+            self.setBoardList([board1], [])
+            if not self.analyzing_paused:
+                self.__sendAnalyze(self.mode == INVERSE_ANALYZING)
+        asyncio.async(coro())
 
     @asyncio.coroutine
     def makeMove(self, board1, move, board2):
@@ -331,7 +344,7 @@ class CECPEngine(ProtocolEngine):
             status = yield from self.queue.get()
         if status == "invalid":
             raise InvalidMove
-        if status == "del":
+        if status == "del" or status == "die":
             raise PlayerIsDead("Killed by foreign forces")
         if status == "int":
             raise TurnInterrupt
@@ -454,8 +467,8 @@ class CECPEngine(ProtocolEngine):
         """ Set an option, which will be sent to the engine, after the
             'readyForOptions' signal has passed.
             If you want to know the possible options, you should go to
-            engineDiscoverer or use the getOption, getOptions and hasOption
-            methods, while you are in your 'readyForOptions' signal handler """
+            engineDiscoverer or use the hasOption method
+            while you are in your 'readyForOptions' signal handler """
         if self.readyMoves:
             log.warning(
                 "Options set after 'readyok' are not sent to the engine",
@@ -477,12 +490,20 @@ class CECPEngine(ProtocolEngine):
             force mode, but some of them do so anyways. """
 
         log.debug("pause: self=%s" % self, extra={"task": self.defname})
-        self.engine.pause()
+        if self.isAnalyzing():
+            self.__stop_analyze()
+            self.analyzing_paused = True
+        else:
+            self.engine.pause()
         return
 
     def resume(self):
         log.debug("resume: self=%s" % self, extra={"task": self.defname})
-        self.engine.resume()
+        if self.isAnalyzing():
+            self.__sendAnalyze(self.mode == INVERSE_ANALYZING)
+            self.analyzing_paused = False
+        else:
+            self.engine.resume()
         return
 
     def hurry(self):
@@ -570,30 +591,30 @@ class CECPEngine(ProtocolEngine):
         print("go", file=self.engine)
         self.engineIsInNotPlaying = False
 
-    def __sendAnalyze(self, inverse=False):
+    def __stop_analyze(self):
+        if self.engineIsAnalyzing:
+            print("exit", file=self.engine)
+            # Some engines (crafty, gnuchess) doesn't respond to exit command
+            # we try to force them to stop with an empty board fen
+            print("setboard 8/8/8/8/8/8/8/8 w - - 0 1", file=self.engine)
+            self.engineIsAnalyzing = False
 
+    def __sendAnalyze(self, inverse=False):
         if inverse and self.board.board.opIsChecked():
             # Many engines don't like positions able to take down enemy
             # king. Therefore we just return the "kill king" move
             # automaticaly
-            self.emit("analyze", [([toAN(
-                self.board, getMoveKillingKing(self.board))], MATE_VALUE - 1, "")])
+            self.emit("analyze", [(self.board.ply, [toAN(
+                self.board, getMoveKillingKing(self.board))], MATE_VALUE - 1, "", "")])
             return
 
-        def stop_analyze():
-            if self.engineIsAnalyzing:
-                print("exit", file=self.engine)
-                # Some engines (crafty, gnuchess) doesn't respond to exit command
-                # we try to force them to stop with an empty board fen
-                print("setboard 8/8/8/8/8/8/8/8 w - - 0 1", file=self.engine)
-                self.engineIsAnalyzing = False
-
         print("post", file=self.engine)
         print("analyze", file=self.engine)
         self.engineIsAnalyzing = True
 
-        loop = asyncio.get_event_loop()
-        loop.call_later(conf.get("max_analysis_spin", 3), stop_analyze)
+        if not conf.get("infinite_analysis", False):
+            loop = asyncio.get_event_loop()
+            loop.call_later(conf.get("max_analysis_spin", 3), self.__stop_analyze)
 
     def __printColor(self):
         if self.features["colors"]:  # or self.mode == INVERSE_ANALYZING:
@@ -720,7 +741,7 @@ class CECPEngine(ProtocolEngine):
 
                     match = anare.match(line)
                     if match:
-                        depth, score, moves = match.groups()
+                        depth, score, time, nodes, moves = match.groups()
 
                         if "mat" in score.lower() or "#" in moves:
                             # Will look either like -Mat 3 or Mat3
@@ -730,9 +751,11 @@ class CECPEngine(ProtocolEngine):
                         else:
                             scoreval = int(score)
 
+                        nps = str(int(int(nodes) / (int(time) / 100))) if int(time) > 0 else ""
+
                         mvstrs = movere.findall(moves)
                         if mvstrs:
-                            self.emit("analyze", [(mvstrs, scoreval, depth.strip())])
+                            self.emit("analyze", [(self.board.ply, mvstrs, scoreval, depth.strip(), nps)])
 
                         continue
 
@@ -947,15 +970,18 @@ class CECPEngine(ProtocolEngine):
         assert self.ready, "Still waiting for done=1"
         return self.features["analyze"]
 
+    def getAnalysisLines(self):
+        return 1
+
+    def minAnalysisLines(self):
+        return 1
+
     def maxAnalysisLines(self):
         return 1
 
     def requestMultiPV(self, setting):
         return 1
 
-    def isAnalyzing(self):
-        return self.mode in (ANALYZING, INVERSE_ANALYZING)
-
     def __repr__(self):
         if self.name:
             return self.name
