@@ -7,10 +7,15 @@ class PlayerIsDead(Exception):
     pass
 
 
+class PassInterrupt(Exception):
+    """ Used instead of returning a move, when a players turn is interrupted but not changed.
+        This may happen when undoMoves doesn't changes the current player """
+    pass
+
+
 class TurnInterrupt(Exception):
     """ Used instead of returning a move, when a players turn is interrupted.
-        Currently this will only happen when undoMoves changes the current
-        player """
+        This may happen when undoMoves changes the current player """
     pass
 
 
@@ -20,6 +25,11 @@ class InvalidMove(Exception):
     pass
 
 
+class GameEnded(Exception):
+    """ Used instead of returning a move on game end """
+    pass
+
+
 class Player(GObject.GObject):
 
     __gsignals__ = {
