@@ -60,6 +60,12 @@ else:
          "vm_args": ["-u"]},
         #    {"protocol": "xboard", "name": "shatranj.py", "country": "us",
         #        "vm_name": PYTHONBIN, "vm_args": ["-u"], "args": ["-xboard"]},
+        {"protocol": "xboard",
+         "name": "fairymax",
+         "country": "nl"},
+        {"protocol": "xboard",
+         "name": "sjaakii",
+         "country": "nl"},
         {"protocol": "xboard",
          "name": "gnuchess",
          "country": "us"},
@@ -249,7 +255,7 @@ class EngineDiscoverer(GObject.GObject):
             altpath = dirname(command) if command else None
             if sys.platform == "win32" and not altpath:
                 altpath = os.path.join(getDataPrefix(), "engines") + ";" + os.path.dirname(sys.executable)
-            path = shutil.which(engine["name"], mode=os.R_OK | os.X_OK, path=altpath)
+            path = shutil.which(command if command else engine["name"], mode=os.R_OK | os.X_OK, path=altpath)
             if path:
                 return None, path
         return False
@@ -280,7 +286,7 @@ class EngineDiscoverer(GObject.GObject):
     @asyncio.coroutine
     def __discoverE(self, engine):
         try:
-            subproc = yield from self.initEngine(engine, BLACK)
+            subproc = yield from self.initEngine(engine, BLACK, False)
             subproc.connect('readyForOptions', self.__discoverE2, engine)
             subproc.prestart()  # Sends the 'start line'
 
@@ -456,7 +462,7 @@ class EngineDiscoverer(GObject.GObject):
 
     def getEngineByName(self, name):
         names = [engine["name"] for engine in self.getEngines()]
-        return self.getEngines()[names.index(name)]
+        return self.getEngines()[names.index(name)] if name in names else None
 
     def getEngineByMd5(self, md5sum, list=[]):
         if not list:
@@ -489,12 +495,10 @@ class EngineDiscoverer(GObject.GObject):
                             if variantClass.cecp_name in option["choices"] or \
                                     variantClass.cecp_name.lower().replace("-", "") in option["choices"]:
                                 engine_variants.append(variantClass.variant)
-        # Fix #1444 Unsupported variant on the home screen
+
         if UCI_without_standard_variant:
-            # this fix causes problems in TaskerManager and newGameDialog
-            # TODO: create correct fix
-            if 0:
-                engine_variants.remove(NORMALCHESS)
+            engine_variants.remove(NORMALCHESS)
+
         return engine_variants
 
     def getName(self, engine=None):
@@ -504,7 +508,7 @@ class EngineDiscoverer(GObject.GObject):
         return engine.get("country")
 
     @asyncio.coroutine
-    def initEngine(self, engine, color):
+    def initEngine(self, engine, color, lowPriority):
         name = engine['name']
         protocol = engine["protocol"]
         protover = 2 if engine.get("protover") is None else engine.get(
@@ -528,7 +532,7 @@ class EngineDiscoverer(GObject.GObject):
             workdir = getEngineDataPrefix()
         warnwords = ("illegal", "error", "exception")
         try:
-            subprocess = SubProcess(path, args=args, warnwords=warnwords, cwd=workdir)
+            subprocess = SubProcess(path, args=args, warnwords=warnwords, cwd=workdir, lowPriority=lowPriority)
             yield from subprocess.start()
         except OSError:
             raise PlayerIsDead
@@ -536,7 +540,7 @@ class EngineDiscoverer(GObject.GObject):
             raise PlayerIsDead
         except GLib.GError:
             raise PlayerIsDead
-        except:
+        except Exception:
             raise PlayerIsDead
 
         engine_proc = attrToProtocol[protocol](subprocess, color, protover,
@@ -570,7 +574,7 @@ class EngineDiscoverer(GObject.GObject):
                          incr=0,
                          moves=0,
                          forcePonderOff=False):
-        engine = yield from self.initEngine(engine, color)
+        engine = yield from self.initEngine(engine, color, False)
 
         def optionsCallback(engine):
             engine.setOptionStrength(diffi, forcePonderOff)
@@ -584,7 +588,7 @@ class EngineDiscoverer(GObject.GObject):
 
     @asyncio.coroutine
     def initAnalyzerEngine(self, engine, mode, variant):
-        engine = yield from self.initEngine(engine, WHITE)
+        engine = yield from self.initEngine(engine, WHITE, True)
 
         def optionsCallback(engine):
             engine.setOptionAnalyzing(mode)
@@ -594,11 +598,12 @@ class EngineDiscoverer(GObject.GObject):
         engine.prestart()
         return engine
 
-    def addEngine(self, name, new_engine, protocol, vm_name, vm_args):
+    def addEngine(self, name, new_engine, protocol, vm_name, vm_args, country):
         engine = {"name": name,
                   "protocol": protocol,
                   "command": new_engine,
-                  "recheck": True}
+                  "recheck": True,
+                  "country": country}
         if vm_name is not None:
             engine["vm_name"] = vm_name
         if vm_args is not None:
@@ -630,19 +635,30 @@ def init_engine(analyzer_type, gamemodel, force=False):
     if analyzer_type == HINT:
         combo_name = "ana_combobox"
         check_name = "analyzer_check"
+        default = True
         mode = ANALYZING
     else:
         combo_name = "inv_ana_combobox"
         check_name = "inv_analyzer_check"
+        default = False
         mode = INVERSE_ANALYZING
 
     analyzer = None
 
-    if conf.get(check_name, True):
+    if conf.get(check_name, default):
         anaengines = list(discoverer.getAnalyzers())
+        if len(anaengines) == 0:
+            return None
+
         engine = discoverer.getEngineByMd5(conf.get(combo_name, 0))
         if engine is None:
-            # Let Stockfish to be default analyzer in Windows installer
+            if sys.platform == "win32":
+                # Let Stockfish to be default analyzer in Windows installer
+                engine = discoverer.getEngineN(-1)
+            else:
+                engine = discoverer.getEngineByName("stockfish")
+
+        if engine is None:
             engine = anaengines[-1]
 
         if gamemodel.variant.variant in discoverer.getEngineVariants(engine):
