@@ -1,7 +1,8 @@
 import os
 import sys
+from urllib.request import urlopen
+from urllib.parse import unquote
 
-from pychess.compat import open, urlopen, unquote
 
 PGN_ENCODING = "latin_1"
 
@@ -18,8 +19,11 @@ def splitUri(uri):
 def protoopen(uri):
     """ Function for opening many things """
 
+    if uri.startswith("file:///"):
+        uri = uri[7:]
+
     try:
-        return open(uri, "rU", encoding=PGN_ENCODING)
+        return open(unquote(uri), "rU", encoding=PGN_ENCODING, newline="")
     except (IOError, OSError):
         pass
 
@@ -38,12 +42,12 @@ def protosave(uri, append=False):
 
     if splitted[0] == "file":
         if append:
-            return open(splitted[1], "a", encoding=PGN_ENCODING)
-        return open(splitted[1], "w")
+            return open(splitted[1], "a", encoding=PGN_ENCODING, newline="")
+        return open(splitted[1], "w", newline="")
     elif len(splitted) == 1:
         if append:
-            return open(splitted[0], "a", encoding=PGN_ENCODING)
-        return open(splitted[0], "w", encoding=PGN_ENCODING)
+            return open(splitted[0], "a", encoding=PGN_ENCODING, newline="")
+        return open(splitted[0], "w", encoding=PGN_ENCODING, newline="")
 
     raise IOError("PyChess doesn't support writing to protocol")
 
