@@ -9,7 +9,6 @@ from gi.repository.GdkPixbuf import Pixbuf
 from pychess.System import conf
 from pychess.System.Log import log
 from pychess.System.prefix import addDataPrefix
-from pychess.widgets.ToggleComboBox import ToggleComboBox
 
 
 def createCombo(combo, data=[], name=None):
@@ -131,9 +130,6 @@ METHODS = (
     (Gtk.Entry, ("get_text", "set_text", "changed")),
     (Gtk.Expander, ("get_expanded", "set_expanded", "notify::expanded")),
     (Gtk.ComboBox, ("get_active", "set_active", "changed")),
-    # Gtk.ToggleComboBox should be listed prior to Gtk.ToggleButton, as it is a
-    # subclass, but requires different handling
-    (ToggleComboBox, ("_get_active", "_set_active", "changed")),
     (Gtk.IconView, ("_get_active", "_set_active", "selection-changed")),
     (Gtk.ToggleButton, ("get_active", "set_active", "toggled")),
     (Gtk.CheckMenuItem, ("get_active", "set_active", "toggled")),
@@ -420,15 +416,11 @@ class GladeWidgets:
             for node in tree.iter():
                 if 'translatable' in node.attrib:
                     node.text = _(node.text)
+                    del node.attrib['translatable']
                 if node.get('name') in ('pixbuf', 'logo'):
                     node.text = addDataPrefix("glade/%s" % node.text)
-            # temp_file = BytesIO()
-            temp_file = addDataPrefix("glade/%s.temp" % filename)
-            tree.write(temp_file, encoding='utf-8', xml_declaration=True)
-            # xml_text = temp_file.getvalue().decode()
-            # self.builder = Gtk.Builder.new_from_string(xml_text, len(xml_text))
-            self.builder = Gtk.Builder()
-            self.builder.add_from_file(temp_file)
+            xml_text = ET.tostring(tree.getroot(), encoding='unicode', method='xml')
+            self.builder = Gtk.Builder.new_from_string(xml_text, -1)
         else:
             self.builder = Gtk.Builder()
             if not no_gettext:
