@@ -1,7 +1,4 @@
-from __future__ import absolute_import
-from __future__ import print_function
 
-from pychess.compat import basestring
 from .lutils.bitboard import iterBits
 from .lutils.LBoard import LBoard
 from .lutils.lmove import RANK, FILE, FCORD, FLAG, PROMOTE_PIECE
@@ -49,37 +46,14 @@ class Board:
             if lboard is None:
                 if setup is True:
                     self.board.applyFen(FEN_START)
-                elif isinstance(setup, basestring):
+                elif isinstance(setup, str):
                     self.board.applyFen(setup)
 
-            wpieces = self.board.boards[WHITE]
-            bpieces = self.board.boards[BLACK]
-
-            for cord in iterBits(wpieces[PAWN]):
-                self.data[RANK(cord)][FILE(cord)] = Piece(WHITE, PAWN)
-            for cord in iterBits(wpieces[KNIGHT]):
-                self.data[RANK(cord)][FILE(cord)] = Piece(WHITE, KNIGHT)
-            for cord in iterBits(wpieces[BISHOP]):
-                self.data[RANK(cord)][FILE(cord)] = Piece(WHITE, BISHOP)
-            for cord in iterBits(wpieces[ROOK]):
-                self.data[RANK(cord)][FILE(cord)] = Piece(WHITE, ROOK)
-            for cord in iterBits(wpieces[QUEEN]):
-                self.data[RANK(cord)][FILE(cord)] = Piece(WHITE, QUEEN)
-            if self.board.kings[WHITE] != -1:
-                self[Cord(self.board.kings[WHITE])] = Piece(WHITE, KING)
-
-            for cord in iterBits(bpieces[PAWN]):
-                self.data[RANK(cord)][FILE(cord)] = Piece(BLACK, PAWN)
-            for cord in iterBits(bpieces[KNIGHT]):
-                self.data[RANK(cord)][FILE(cord)] = Piece(BLACK, KNIGHT)
-            for cord in iterBits(bpieces[BISHOP]):
-                self.data[RANK(cord)][FILE(cord)] = Piece(BLACK, BISHOP)
-            for cord in iterBits(bpieces[ROOK]):
-                self.data[RANK(cord)][FILE(cord)] = Piece(BLACK, ROOK)
-            for cord in iterBits(bpieces[QUEEN]):
-                self.data[RANK(cord)][FILE(cord)] = Piece(BLACK, QUEEN)
-            if self.board.kings[BLACK] != -1:
-                self[Cord(self.board.kings[BLACK])] = Piece(BLACK, KING)
+            for color in (BLACK, WHITE):
+                pieces = self.board.boards[color]
+                for piece in (PAWN, KNIGHT, BISHOP, ROOK, QUEEN, KING):
+                    for cord in iterBits(pieces[piece]):
+                        self.data[RANK(cord)][FILE(cord)] = Piece(color, piece)
 
             if self.variant in DROP_VARIANTS:
                 for color in (BLACK, WHITE):
