@@ -34,6 +34,9 @@ class TimeModel(GObject.GObject):
         self.gain = gain
         self.secs = secs
 
+        # to know if game is played on ICS or not
+        self.gamemodel = None
+
         # in FICS games we don't count gain
         self.handle_gain = True
 
@@ -96,9 +99,9 @@ class TimeModel(GObject.GObject):
             return False
         return True
 
-        ############################################################################
-        # Interacting                                                              #
-        ############################################################################
+    ############################################################################
+    # Interacting                                                              #
+    ############################################################################
 
     def setMovingColor(self, movingColor):
         self.movingColor = movingColor
@@ -115,7 +118,10 @@ class TimeModel(GObject.GObject):
                 ticker -= time() - self.counter
         else:
             # FICS rule
-            if self.ply >= 1:
+            if self.gamemodel.isPlayingICSGame():
+                if self.ply >= 1:
+                    self.started = True
+            else:
                 self.started = True
         if self.moves == 0:
             self.intervals[self.movingColor].append(ticker)
@@ -255,3 +261,7 @@ class TimeModel(GObject.GObject):
     def hasBWTimes(self, bmovecount, wmovecount):
         return len(self.intervals[BLACK]) > bmovecount and len(self.intervals[
             WHITE]) > wmovecount
+
+    def isBlitzFide(self):
+        val = 60 * self.minutes + 60 * (self.gain if self.handle_gain else 0)
+        return 300 <= val and val <= 600  # Between 5 and 10 minutes for 60 moves (estimation)
