@@ -1,11 +1,9 @@
-from __future__ import print_function
 import os
 import atexit
 import gettext
 import sqlite3
 import struct
 
-from pychess.compat import memoryview
 from pychess.System.prefix import addDataPrefix, isInstalled
 
 db_path = os.path.join(addDataPrefix("eco.db"))
