@@ -8,7 +8,7 @@ from pychess.Utils.const import SAN, AN, LAN, ENPASSANT, EMPTY, PAWN, KING_CASTL
     reprFile, reprRank, chr2Sign, cordDic, reprSign, reprCord, reprSignSittuyin, reprSignMakruk,\
     QUEEN, KNIGHT, BISHOP, ROOK, KING, NORMALCHESS, NORMAL_MOVE, PROMOTIONS, WHITE, BLACK, DROP,\
     FAN_PIECES, SITTUYINCHESS, FISCHERRANDOMCHESS, SUICIDECHESS, MAKRUKCHESS, CAMBODIANCHESS,\
-    ATOMICCHESS, WILDCASTLECHESS, WILDCASTLESHUFFLECHESS,\
+    GIVEAWAYCHESS, ATOMICCHESS, WILDCASTLECHESS, WILDCASTLESHUFFLECHESS, HORDECHESS,\
     chrU2Sign, CASTLE_KR, CASTLE_SAN, QUEEN_PROMOTION, NULL_MOVE, FAN
 from pychess.Utils.repr import reprPiece, localReprSign
 from pychess.Utils.lutils.lmovegen import genAllMoves, genPieceMoves, newMove
@@ -66,7 +66,7 @@ def parseAny(board, algnot):
 
 def determineAlgebraicNotation(algnot):
     upnot = algnot.upper()
-    if upnot in ("O-O", "O-O-O", "0-0", "0-0-0"):
+    if upnot in ("O-O", "O-O-O", "0-0", "0-0-0", "OO", "OOO", "00", "000"):
         return SAN
 
     # Test for e2-e4
@@ -286,7 +286,7 @@ def parseSAN(board, san):
     c = notat[-1]
     if c in "KQRBNSMFkqrbnsmf.":
         c = c.lower()
-        if c == "k" and board.variant != SUICIDECHESS:
+        if c == "k" and board.variant != SUICIDECHESS and board.variant != GIVEAWAYCHESS:
             raise ParsingError(san, _("invalid promoted piece"), board.asFen())
         elif c == "." and board.variant in (CAMBODIANCHESS, MAKRUKCHESS,
                                             SITTUYINCHESS):
@@ -306,7 +306,7 @@ def parseSAN(board, san):
 
     if notat[0] in "O0o":
         fcord = board.ini_kings[color]
-        flag = KING_CASTLE if notat == "O-O" or notat == "0-0" or notat == "o-o" else QUEEN_CASTLE
+        flag = KING_CASTLE if notat in ("O-O", "0-0", "o-o", "OO", "00", "oo") else QUEEN_CASTLE
         side = flag - QUEEN_CASTLE
         if FILE(fcord) == 3 and board.variant in (WILDCASTLECHESS,
                                                   WILDCASTLESHUFFLECHESS):
@@ -330,9 +330,31 @@ def parseSAN(board, san):
             piece = chrU2Sign[notat[0]]
         return newMove(piece, tcord, DROP)
 
+    # standard piece letters
     if notat[0] in "QRBKNSMF":
         piece = chrU2Sign[notat[0]]
         notat = notat[1:]
+    # unambigious lowercase piece letters
+    elif notat[0] in "qrknsm":
+        piece = chr2Sign[notat[0]]
+        notat = notat[1:]
+    # a lowercase bishop letter or a pawn capture
+    elif notat[0] == "b" and len(notat) > 2 and board.variant == NORMALCHESS:
+        tcord = cordDic[notat[-2:]]
+        trank = int(notat[-1])
+        # if from and to lines are not neighbours -> Bishop
+        if abs(ord(notat[0]) - ord(notat[-2])) > 1:
+            piece = chr2Sign[notat[0]]
+            notat = notat[1:]
+        # if from and to lines are neighbours (or the same) but to is an empty square
+        # which can't be en-passant square target -> Bishop
+        elif board.arBoard[tcord] == EMPTY and ((color == BLACK and trank != 3) or (color == WHITE and trank != 6)):
+            piece = chr2Sign[notat[0]]
+            notat = notat[1:]
+        # elif "ba3", "bc3" ,"ba6", "bc6"
+        # these can be Bishop or Pawn moves, but we don't try to introspect them (sorry)
+        else:
+            piece = PAWN
     else:
         piece = PAWN
         if notat[-1] in "18" and flag == NORMAL_MOVE and board.variant != SITTUYINCHESS:
@@ -367,7 +389,7 @@ def parseSAN(board, san):
 
     # In suicide promoting to king is valid, so
     # more than 1 king per side can exist !
-    if board.variant != SUICIDECHESS and piece == KING:
+    if board.variant != SUICIDECHESS and board.variant != GIVEAWAYCHESS and piece == KING:
         return newMove(board.kings[color], tcord, flag)
 
     # If there is any extra location info, like in the move Bexd1 or Nh3f4 we
@@ -396,8 +418,13 @@ def parseSAN(board, san):
         else:
             if color == WHITE:
                 pawns = board.boards[WHITE][PAWN]
-                fcord = tcord - 16 if RANK(tcord) == 3 and not (
-                    pawns & fileBits[FILE(tcord)] & rankBits[2]) else tcord - 8
+                # In horde white pawns on first rank may move two squares also
+                if board.variant == HORDECHESS and RANK(tcord) == 2 and not (
+                        pawns & fileBits[FILE(tcord)] & rankBits[1]):
+                    fcord = tcord - 16
+                else:
+                    fcord = tcord - 16 if RANK(tcord) == 3 and not (
+                        pawns & fileBits[FILE(tcord)] & rankBits[2]) else tcord - 8
             else:
                 pawns = board.boards[BLACK][PAWN]
                 fcord = tcord + 16 if RANK(tcord) == 4 and not (
@@ -570,7 +597,8 @@ def parseAN(board, an):
     flag = NORMAL_MOVE
 
     if len(an) > 4 and not an[-1] in "QRBNMSFqrbnmsf":
-        if board.variant != SUICIDECHESS or board.variant == SUICIDECHESS and not an[
+        if (board.variant != SUICIDECHESS and board.variant != GIVEAWAYCHESS) or \
+            (board.variant == SUICIDECHESS or board.variant == GIVEAWAYCHESS) and not an[
                 -1] in "Kk":
             raise ParsingError(an, "invalid promoted piece", board.asFen())
 
@@ -611,6 +639,7 @@ def parseAN(board, an):
 
     return newMove(fcord, tcord, flag)
 
+
 ################################################################################
 # toFAN                                                                        #
 ################################################################################
@@ -651,6 +680,7 @@ def toFAN(board, move):
     else:
         return san.translate(san2BlackFanDic)
 
+
 ################################################################################
 # parseFAN                                                                     #
 ################################################################################
