@@ -12,7 +12,7 @@ import pychess
 from pychess.System.Log import log
 
 from pychess import ic
-from pychess.Utils.const import NAME
+from pychess.Utils.const import NAME, FISCHERRANDOMCHESS
 from .managers.SeekManager import SeekManager
 from .managers.FingerManager import FingerManager
 from .managers.NewsManager import NewsManager
@@ -293,8 +293,10 @@ class FICSConnection(Connection):
                 self.client.lines.datagram_mode = True
 
                 ic.GAME_TYPES_BY_SHORT_FICS_NAME["B"] = ic.GAME_TYPES["bullet"]
+                ic.VARIANT_GAME_TYPES[FISCHERRANDOMCHESS] = ic.GAME_TYPES["w22"]
             else:
                 ic.GAME_TYPES_BY_SHORT_FICS_NAME["B"] = ic.GAME_TYPES["bughouse"]
+                ic.VARIANT_GAME_TYPES[FISCHERRANDOMCHESS] = ic.GAME_TYPES["wild/fr"]
 
             self.client.run_command("iset defprompt 1")
             self.client.run_command("iset ms 1")
@@ -363,12 +365,18 @@ class FICSMainConnection(FICSConnection):
         self.games = FICSGames(self)
         self.seeks = FICSSeeks(self)
         self.challenges = FICSChallenges(self)
+        self.archived_examine = None
         self.examined_game = None
         self.stored_owner = self.username
         self.history_owner = self.username
         self.journal_owner = self.username
         self.set_user_vars = False
 
+        self.offline_lecture = False
+        self.lecture_skip_event = asyncio.Event()  # set when 'Go on' button pressed
+        self.lecture_pause_event = asyncio.Event()  # set when 'Pause' button pressed
+        self.lecture_exit_event = asyncio.Event()  # set when 'Exit' button pressed
+
     def close(self):
         if isinstance(self.client, PredictionsTelnet) and self.set_user_vars:
             self.client.run_command("set open 0")
@@ -430,6 +438,21 @@ class FICSMainConnection(FICSConnection):
         self.seeks.start()
         self.challenges.start()
 
+        # This block may useful if one wants to create
+        # unit test lines from real life fics output
+        if False:
+            self.client.run_command("set seek 0")
+            self.client.run_command("set shout 0")
+            self.client.run_command("set cshout 0")
+            self.client.run_command("iset seekinfo 0")
+            self.client.run_command("iset seekremove 0")
+            self.client.run_command("iset showownseek 0")
+            self.client.run_command("iset allresults 0")
+            self.client.run_command("iset pin 0")
+            self.client.run_command("set open 0")
+            self.client.run_command("set gin 0")
+            self.client.run_command("set availinfo 0")
+
     def start_helper_manager(self, set_user_vars):
         # if guest accounts disabled we will handle players in the main connection
         if self.FatICS or self.USCN or self.ICC:
