@@ -11,8 +11,8 @@ from gi.repository import GObject
 
 from pychess.System import uistuff, conf
 from pychess.widgets import mainwindow
-from .FICSConnection import FICSMainConnection, FICSHelperConnection, LogOnException
-from .ICLounge import ICLounge
+from pychess.ic.FICSConnection import FICSMainConnection, FICSHelperConnection, LogOnException
+from pychess.perspectives import perspective_manager
 
 host = None
 port = None
@@ -132,6 +132,12 @@ class ICLogon(object):
     def on_logOnAsGuest_toggled(self, widget):
         names = self.get_user_names()
         self.widgets["nameEntry"].set_text(names[1] if widget.get_active() else names[0])
+        if self.ics == "ICC":
+            self.widgets["nameLabel"].set_sensitive(not widget.get_active())
+            self.widgets["nameEntry"].set_sensitive(not widget.get_active())
+        else:
+            self.widgets["nameLabel"].set_sensitive(True)
+            self.widgets["nameEntry"].set_sensitive(True)
         self.widgets["passwordLabel"].set_sensitive(not widget.get_active())
         self.widgets["passEntry"].set_sensitive(not widget.get_active())
         conf.set("asGuestCheck", widget.get_active(), section=self.ics)
@@ -142,7 +148,8 @@ class ICLogon(object):
             model = combo.get_model()
             self.ics = model[tree_iter][0]
             # print("Selected: %s" % self.ics)
-            self.widgets["logOnAsGuest"].set_active(conf.get("asGuestCheck", False, section=self.ics))
+            self.widgets["logOnAsGuest"].set_active(conf.get("asGuestCheck", True, section=self.ics))
+            self.on_logOnAsGuest_toggled(self.widgets["logOnAsGuest"])
             self.user_name_set_value(self.widgets["nameEntry"], conf.get("usernameEntry", "", section=self.ics))
             self.password_set_value(self.widgets["passEntry"], conf.get("passwordEntry", "", section=self.ics))
             default_host = "freechess.org" if self.ics == "FICS" else "chessclub.com"
@@ -301,7 +308,13 @@ class ICLogon(object):
         if self.host not in ("localhost", "chessclub.com"):
             self.helperconn = FICSHelperConnection(self.connection, self.host, ports)
             self.helperconn.connect("error", self.onHelperConnectionError)
-            self.helperconn_task = asyncio.async(self.helperconn.start())
+
+            @asyncio.coroutine
+            def coro():
+                yield from self.main_connected_event.wait()
+                yield from self.helperconn.start()
+
+            self.helperconn_task = asyncio.async(coro())
 
     def onHelperConnectionError(self, connection, error):
         if self.helperconn is not None:
@@ -332,7 +345,8 @@ class ICLogon(object):
         if connection.ICC:
             self.connection.start_helper_manager(True)
 
-        self.lounge = ICLounge(connection, self.helperconn, self.host)
+        self.lounge = perspective_manager.get_perspective("fics")
+        self.lounge.open_lounge(connection, self.helperconn, self.host)
         self.hide()
         self.lounge.show()
         self.lounge.connect("logout",
