@@ -7,6 +7,7 @@ from pychess.Utils.const import chr2Sign, WHITE, BLACK
 from pychess.Utils.Piece import Piece
 from pychess.Utils.SetupModel import SetupModel, SetupPlayer
 from pychess.System import uistuff
+from pychess.System.prefix import addDataPrefix
 from pychess.widgets.BoardControl import BoardControl
 from pychess.widgets.PieceWidget import PieceWidget
 from pychess.widgets import mainwindow
@@ -20,6 +21,13 @@ def formatted(q):
     return q[1:-1].replace("'", "")
 
 
+__title__ = _("Filters")
+
+__icon__ = addDataPrefix("glade/panel_filter.svg")
+
+__desc__ = _("Filters panel can filter game list by various conditions")
+
+
 class FilterPanel(Gtk.TreeView):
     def __init__(self, persp):
         GObject.GObject.__init__(self)
@@ -350,12 +358,9 @@ class FilterPanel(Gtk.TreeView):
         (iter_first, iter_last) = textbuffer.get_bounds()
         text = textbuffer.get_text(iter_first, iter_last, False)
         if text:
-            try:
-                q = ast.literal_eval(text)
-                self.persp.chessfile.set_scout_filter(q)
-                need_update = True
-            except:
-                pass
+            q = ast.literal_eval(text)
+            self.persp.chessfile.set_scout_filter(q)
+            need_update = True
 
         if need_update and self.filtered:
             self.persp.gamelist.load_games()
@@ -474,10 +479,7 @@ class FilterPanel(Gtk.TreeView):
 
         # Add a BoardControl widget to dock and initialize it with a new SetupModel
         self.setupmodel = SetupModel()
-        self.board_control = BoardControl(self.setupmodel,
-                                          {},
-                                          setup_position=True,
-                                          setup_sub_fen=True)
+        self.board_control = BoardControl(self.setupmodel, {}, setup_position=True)
         self.setupmodel.curplayer = SetupPlayer(self.board_control)
         self.setupmodel.connect("game_changed", self.game_changed)
 
