@@ -1,24 +1,20 @@
 import os
 import threading
-import traceback
-from io import StringIO
 
 from gi.repository import Gtk, GObject, GLib
 
 from pychess.Utils.const import FIRST_PAGE, NEXT_PAGE
-from pychess.System.Log import log
+from pychess.Utils.IconLoader import load_icon
 from pychess.perspectives import Perspective, perspective_manager
 from pychess.perspectives.database.gamelist import GameList
-from pychess.perspectives.database.SwitcherPanel import SwitcherPanel
 from pychess.perspectives.database.OpeningTreePanel import OpeningTreePanel
 from pychess.perspectives.database.FilterPanel import FilterPanel
 from pychess.perspectives.database.PreviewPanel import PreviewPanel
-from pychess.System.prefix import addDataPrefix, addUserConfigPrefix
+from pychess.System.prefix import addUserConfigPrefix
 from pychess.widgets.pydock.PyDockTop import PyDockTop
-from pychess.widgets.pydock import EAST, SOUTH, CENTER, NORTH
+from pychess.widgets.pydock import EAST, SOUTH, CENTER
+from pychess.widgets import mainwindow, new_notebook, createImage, createAlignment, gtk_close
 from pychess.widgets import gamewidget
-from pychess.widgets import mainwindow
-from pychess.widgets import dock_panel_tab
 from pychess.Database.model import create_indexes, drop_indexes
 from pychess.Database.PgnImport import PgnImport, download_file
 from pychess.Database.JvR import JvR
@@ -26,12 +22,7 @@ from pychess.Savers import fen, epd
 from pychess.Savers.pgn import PGNFile
 from pychess.System.protoopen import protoopen
 
-
-def new_notebook():
-    notebook = Gtk.Notebook()
-    notebook.set_show_tabs(False)
-    notebook.set_show_border(False)
-    return notebook
+pgn_icon = load_icon(24, "application-x-chess-pgn", "pychess")
 
 
 class Database(GObject.GObject, Perspective):
@@ -46,6 +37,7 @@ class Database(GObject.GObject, Perspective):
         GObject.GObject.__init__(self)
         Perspective.__init__(self, "database", _("Database"))
         self.widgets = gamewidget.getWidgets()
+        self.first_run = True
         self.chessfile = None
         self.chessfiles = []
         self.importer = None
@@ -54,7 +46,9 @@ class Database(GObject.GObject, Perspective):
         self.opening_tree_panels = []
         self.preview_panels = []
         self.notebooks = {}
+        self.page_dict = {}
         self.connect("chessfile_opened0", self.on_chessfile_opened0)
+        self.dockLocation = addUserConfigPrefix("pydock-database.xml")
 
     @property
     def gamelist(self):
@@ -93,19 +87,14 @@ class Database(GObject.GObject, Perspective):
         self.save_as_button.set_tooltip_text(_("Save to PGN file as..."))
         self.save_as_button.connect("clicked", self.on_save_as_clicked)
 
-        self.close_button = Gtk.ToolButton.new_from_stock(Gtk.STOCK_CLOSE)
-        self.close_button.set_tooltip_text(_("Close"))
-        self.close_button.connect("clicked", self.close)
-
     def init_layout(self):
         perspective_widget = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
         perspective_manager.set_perspective_widget("database", perspective_widget)
 
-        self.switcher_panel = SwitcherPanel(self)
-        self.notebooks["gamelist"] = new_notebook()
-        self.notebooks["opening_tree"] = new_notebook()
-        self.notebooks["filter"] = new_notebook()
-        self.notebooks["preview"] = new_notebook()
+        self.notebooks = {"gamelist": new_notebook()}
+        self.main_notebook = self.notebooks["gamelist"]
+        for panel in self.sidePanels:
+            self.notebooks[panel.__name__] = new_notebook(panel.__name__)
 
         self.spinner = Gtk.Spinner()
         self.spinner.set_size_request(50, 50)
@@ -120,6 +109,20 @@ class Database(GObject.GObject, Perspective):
         self.progress_dialog.get_content_area().pack_start(self.progressbar1, True, True, 0)
         self.progress_dialog.get_content_area().show_all()
 
+        # Initing headbook
+
+        align = createAlignment(4, 4, 0, 4)
+        align.set_property("yscale", 0)
+
+        self.headbook = Gtk.Notebook()
+        self.headbook.set_name("headbook")
+        self.headbook.set_scrollable(True)
+        align.add(self.headbook)
+        perspective_widget.pack_start(align, False, True, 0)
+        self.headbook.connect_after("switch-page", self.on_switch_page)
+
+        # The dock
+
         self.dock = PyDockTop("database", self)
         align = Gtk.Alignment()
         align.show()
@@ -127,50 +130,23 @@ class Database(GObject.GObject, Perspective):
         self.dock.show()
         perspective_widget.pack_start(align, True, True, 0)
 
-        dockLocation = addUserConfigPrefix("pydock-database.xml")
+        self.docks["gamelist"] = (Gtk.Label(label="gamelist"), self.notebooks["gamelist"], None)
+        for panel in self.sidePanels:
+            self.docks[panel.__name__][1] = self.notebooks[panel.__name__]
 
-        docks = {
-            "gamelist": (Gtk.Label(label="gamelist"), self.notebooks["gamelist"]),
-            "switcher": (dock_panel_tab(_("Databases"), "", addDataPrefix("glade/panel_database.svg")), self.switcher_panel.alignment),
-            "openingtree": (dock_panel_tab(_("Openings"), "", addDataPrefix("glade/panel_book.svg")), self.notebooks["opening_tree"]),
-            "filter": (dock_panel_tab(_("Filters"), "", addDataPrefix("glade/panel_filter.svg")), self.notebooks["filter"]),
-            "preview": (dock_panel_tab(_("Preview"), "", addDataPrefix("glade/panel_games.svg")), self.notebooks["preview"]),
-        }
+        self.load_from_xml()
 
-        if os.path.isfile(dockLocation):
-            try:
-                self.dock.loadFromXML(dockLocation, docks)
-            except Exception as e:
-                stringio = StringIO()
-                traceback.print_exc(file=stringio)
-                error = stringio.getvalue()
-                log.error("Dock loading error: %s\n%s" % (e, error))
-                msg_dia = Gtk.MessageDialog(mainwindow(),
-                                            type=Gtk.MessageType.ERROR,
-                                            buttons=Gtk.ButtonsType.CLOSE)
-                msg_dia.set_markup(_(
-                    "<b><big>PyChess was unable to load your panel settings</big></b>"))
-                msg_dia.format_secondary_text(_(
-                    "Your panel settings have been reset. If this problem repeats, \
-                    you should report it to the developers"))
-                msg_dia.run()
-                msg_dia.hide()
-                os.remove(dockLocation)
-                for title, panel in docks.values():
-                    title.unparent()
-                    panel.unparent()
-
-        if not os.path.isfile(dockLocation):
-            leaf = self.dock.dock(docks["gamelist"][1], CENTER, docks["gamelist"][0], "gamelist")
+        # Default layout of side panels
+        if not os.path.isfile(self.dockLocation):
+            leaf = self.dock.dock(self.docks["gamelist"][1], CENTER, self.docks["gamelist"][0], "gamelist")
             leaf.setDockable(False)
 
-            leaf.dock(docks["switcher"][1], NORTH, docks["switcher"][0], "switcher")
-            leaf = leaf.dock(docks["openingtree"][1], EAST, docks["openingtree"][0], "openingtree")
-            leaf = leaf.dock(docks["filter"][1], CENTER, docks["filter"][0], "filter")
-            leaf.dock(docks["preview"][1], SOUTH, docks["preview"][0], "preview")
+            leaf = leaf.dock(self.docks["OpeningTreePanel"][1], EAST, self.docks["OpeningTreePanel"][0], "OpeningTreePanel")
+            leaf = leaf.dock(self.docks["FilterPanel"][1], CENTER, self.docks["FilterPanel"][0], "FilterPanel")
+            leaf.dock(self.docks["PreviewPanel"][1], SOUTH, self.docks["PreviewPanel"][0], "PreviewPanel")
 
         def unrealize(dock):
-            dock.saveToXML(dockLocation)
+            dock.saveToXML(self.dockLocation)
             dock._del()
 
         self.dock.connect("unrealize", unrealize)
@@ -178,10 +154,20 @@ class Database(GObject.GObject, Perspective):
         self.dock.show_all()
         perspective_widget.show_all()
 
-        perspective_manager.set_perspective_toolbuttons("database", [
-            self.import_button, self.save_as_button, self.close_button])
+        perspective_manager.set_perspective_menuitems("database", self.menuitems)
 
-        self.switcher_panel.connect("chessfile_switched", self.on_chessfile_switched)
+        perspective_manager.set_perspective_toolbuttons("database", [
+            self.import_button, self.save_as_button])
+
+    def on_switch_page(self, notebook, page, page_num):
+        if page in self.page_dict:
+            self.chessfile = self.page_dict[page][0]
+            i = self.chessfiles.index(self.chessfile)
+
+            self.notebooks["gamelist"].set_current_page(i)
+            self.notebooks["OpeningTreePanel"].set_current_page(i)
+            self.notebooks["FilterPanel"].set_current_page(i)
+            self.notebooks["PreviewPanel"].set_current_page(i)
 
     def set_sensitives(self, on):
         self.import_button.set_sensitive(on)
@@ -191,8 +177,9 @@ class Database(GObject.GObject, Perspective):
         self.widgets["import_twic"].set_sensitive(on)
 
     def open_chessfile(self, filename):
-        if self.chessfile is None:
+        if self.first_run:
             self.init_layout()
+            self.first_run = False
 
         perspective_manager.activate_perspective("database")
 
@@ -248,6 +235,12 @@ class Database(GObject.GObject, Perspective):
         self.progress_dialog.hide()
 
     def on_chessfile_opened0(self, persp, chessfile):
+        page = Gtk.Alignment()
+        tabcontent, close_button = self.get_tabcontent(chessfile)
+        self.headbook.append_page(page, tabcontent)
+        self.page_dict[page] = (chessfile, close_button)
+        page.show_all()
+
         gamelist = GameList(self)
         self.gamelists.append(gamelist)
         opening_tree_panel = OpeningTreePanel(self)
@@ -258,11 +251,11 @@ class Database(GObject.GObject, Perspective):
         self.preview_panels.append(preview_panel)
 
         self.notebooks["gamelist"].append_page(gamelist.box)
-        self.notebooks["opening_tree"].append_page(opening_tree_panel.box)
-        self.notebooks["filter"].append_page(filter_panel.box)
-        self.notebooks["preview"].append_page(preview_panel.box)
+        self.notebooks["OpeningTreePanel"].append_page(opening_tree_panel.box)
+        self.notebooks["FilterPanel"].append_page(filter_panel.box)
+        self.notebooks["PreviewPanel"].append_page(preview_panel.box)
 
-        self.on_chessfile_switched(None, self.chessfile)
+        self.headbook.set_current_page(self.headbook.get_n_pages() - 1)
 
         gamelist.load_games()
         opening_tree_panel.update_tree(load_games=False)
@@ -270,18 +263,23 @@ class Database(GObject.GObject, Perspective):
         self.set_sensitives(True)
         self.emit("chessfile_opened", chessfile)
 
-    def close(self, widget):
-        if self.chessfile is not None and self.chessfile in self.chessfiles:
-            i = self.chessfiles.index(self.chessfile)
-            if self.chessfile.path is not None:
+    def close(self, close_button):
+        for page in list(self.page_dict.keys()):
+            if self.page_dict[page][1] == close_button:
+                chessfile = self.page_dict[page][0]
+                i = self.chessfiles.index(chessfile)
                 self.notebooks["gamelist"].remove_page(i)
-                self.notebooks["opening_tree"].remove_page(i)
-                self.notebooks["filter"].remove_page(i)
-                self.notebooks["preview"].remove_page(i)
+                self.notebooks["OpeningTreePanel"].remove_page(i)
+                self.notebooks["FilterPanel"].remove_page(i)
+                self.notebooks["PreviewPanel"].remove_page(i)
                 del self.gamelists[i]
                 del self.filter_panels[i]
                 del self.chessfiles[i]
-                self.chessfile.close()
+                chessfile.close()
+
+                del self.page_dict[page]
+                self.headbook.remove_page(self.headbook.page_num(page))
+                break
 
         if len(self.chessfiles) == 0:
             self.set_sensitives(False)
@@ -289,15 +287,6 @@ class Database(GObject.GObject, Perspective):
 
         self.emit("chessfile_closed")
 
-    def on_chessfile_switched(self, switcher, chessfile):
-        self.chessfile = chessfile
-        i = self.chessfiles.index(chessfile)
-
-        self.notebooks["gamelist"].set_current_page(i)
-        self.notebooks["opening_tree"].set_current_page(i)
-        self.notebooks["filter"].set_current_page(i)
-        self.notebooks["preview"].set_current_page(i)
-
     def on_import_endgame_nl(self):
         self.do_import(JvR)
 
@@ -413,6 +402,41 @@ class Database(GObject.GObject, Perspective):
                 self.importer.do_cancel()
             self.progress_dialog.hide()
 
+    # @profile_me
+    def importing(self, filenames):
+        drop_indexes(self.chessfile.engine)
+
+        self.importer = PgnImport(self.chessfile, append_pgn=True)
+        self.importer.initialize()
+        for i, filename in enumerate(filenames):
+            GLib.idle_add(self.progressbar0.set_fraction, i / float(len(filenames)))
+            # GLib.idle_add(self.progressbar0.set_text, filename)
+            if self.importer.cancel:
+                break
+            if isinstance(filename, tuple):
+                info_link, pgn_link = filename
+                self.importer.do_import(pgn_link, info=info_link, progressbar=self.progressbar1)
+            else:
+                self.importer.do_import(filename, progressbar=self.progressbar1)
+
+        GLib.idle_add(self.progressbar1.set_text, _("Recreating indexes..."))
+
+        # .sqlite
+        create_indexes(self.chessfile.engine)
+
+        # .scout
+        self.chessfile.init_scoutfish()
+
+        # .bin
+        self.chessfile.init_chess_db()
+
+        self.chessfile.set_tag_filter(None)
+        self.chessfile.set_fen_filter(None)
+        self.chessfile.set_scout_filter(None)
+        GLib.idle_add(self.gamelist.load_games)
+        GLib.idle_add(self.emit, "chessfile_imported", self.chessfile)
+        GLib.idle_add(self.progress_dialog.hide)
+
     def do_import(self, filenames):
         self.progress_dialog.set_title(_("Import"))
         self.spinner.hide()
@@ -423,42 +447,7 @@ class Database(GObject.GObject, Perspective):
         self.progressbar1.show()
         self.progressbar1.set_text(_("Preparing to start import..."))
 
-        # @profile_me
-        def importing():
-            drop_indexes(self.chessfile.engine)
-
-            self.importer = PgnImport(self.chessfile, append_pgn=True)
-            self.importer.initialize()
-            for i, filename in enumerate(filenames):
-                GLib.idle_add(self.progressbar0.set_fraction, i / float(len(filenames)))
-                # GLib.idle_add(self.progressbar0.set_text, filename)
-                if self.importer.cancel:
-                    break
-                if isinstance(filename, tuple):
-                    info_link, pgn_link = filename
-                    self.importer.do_import(pgn_link, info=info_link, progressbar=self.progressbar1)
-                else:
-                    self.importer.do_import(filename, progressbar=self.progressbar1)
-
-            GLib.idle_add(self.progressbar1.set_text, _("Recreating indexes..."))
-
-            # .sqlite
-            create_indexes(self.chessfile.engine)
-
-            # .scout
-            self.chessfile.init_scoutfish()
-
-            # .bin
-            self.chessfile.init_chess_db()
-
-            self.chessfile.set_tag_filter(None)
-            self.chessfile.set_fen_filter(None)
-            self.chessfile.set_scout_filter(None)
-            GLib.idle_add(self.gamelist.load_games)
-            GLib.idle_add(self.emit, "chessfile_imported", self.chessfile)
-            GLib.idle_add(self.progress_dialog.hide)
-
-        thread = threading.Thread(target=importing)
+        thread = threading.Thread(target=self.importing, args=(filenames, ))
         thread.daemon = True
         thread.start()
 
@@ -491,6 +480,33 @@ class Database(GObject.GObject, Perspective):
 
         dialog.destroy()
 
+    def get_tabcontent(self, chessfile):
+        tabcontent = createAlignment(0, 0, 0, 0)
+        hbox = Gtk.HBox()
+        hbox.set_spacing(4)
+        hbox.pack_start(createImage(pgn_icon), False, True, 0)
+
+        close_button = Gtk.Button()
+        close_button.set_property("can-focus", False)
+        close_button.add(createImage(gtk_close))
+        close_button.set_relief(Gtk.ReliefStyle.NONE)
+        close_button.set_size_request(20, 18)
+        close_button.connect("clicked", self.close)
+        hbox.pack_end(close_button, False, True, 0)
+
+        name, ext = os.path.splitext(chessfile.path)
+        basename = os.path.basename(name)
+        info = "%s.%s" % (basename, ext[1:])
+        tooltip = "%s\ncontaining %s games" % (chessfile.path, chessfile.count)
+        tabcontent.set_tooltip_text(tooltip)
+
+        label = Gtk.Label(info)
+        hbox.pack_start(label, False, True, 0)
+
+        tabcontent.add(hbox)
+        tabcontent.show_all()
+        return tabcontent, close_button
+
 
 def get_latest_twic():
     filename = download_file("http://www.theweekinchess.com/twic")
