@@ -13,11 +13,6 @@ from pychess.Variants import variants
 from pychess.Database.model import game, event, site, pl1, pl2
 
 
-def createImage(pixbuf):
-    image = Gtk.Image()
-    image.set_from_pixbuf(pixbuf)
-    return image
-
 cols = (game.c.id, pl1.c.name, game.c.white_elo, pl2.c.name, game.c.black_elo,
         game.c.result, game.c.date_year, event.c.name, site.c.name, game.c.round,
         game.c.ply_count, game.c.eco, game.c.time_control, game.c.variant, game.c.fen)
