@@ -2,6 +2,7 @@
 
 import re
 import datetime
+from math import floor
 
 from gi.repository import Gtk
 from gi.repository import Pango
@@ -74,6 +75,7 @@ class Sidepanel:
         color4 = Gdk.RGBA(red=0.8, green=0.0, blue=0.0)
         color5 = Gdk.RGBA(red=1.0, green=0.0, blue=0.0)
 
+        self.need_remove_variation = None
         self.remove_vari_tag = self.textbuffer.create_tag("remove-variation")
         self.rmv_cid = self.remove_vari_tag.connect("event", self.tag_event_handler)
 
@@ -195,7 +197,7 @@ class Sidepanel:
             if node is None:
                 return
 
-            self.remove_variation(node)
+            self.need_remove_variation = node
 
         return False
 
@@ -272,7 +274,9 @@ class Sidepanel:
         # left mouse click
         if event.button == 1:
             if "vari" in node:
-                # tag_event_handler() will handle
+                if self.need_remove_variation is not None:
+                    self.remove_variation(self.need_remove_variation)
+                    self.need_remove_variation = None
                 return True
             elif "comment" in node:
                 self.edit_comment(board=board, index=node["index"])
@@ -283,10 +287,6 @@ class Sidepanel:
         elif event.button == 3:
             self.menu = Gtk.Menu()
 
-            menuitem = Gtk.MenuItem(_("Copy PGN"))
-            menuitem.connect('activate', self.copy_pgn)
-            self.menu.append(menuitem)
-
             if node is not None:
                 position = -1
                 for index, child in enumerate(board.children):
@@ -312,10 +312,14 @@ class Sidepanel:
                     self.menu.append(menuitem)
 
                 symbol_menu1 = Gtk.Menu()
-                for nag, menutext in (("$1", "!"), ("$2", "?"), ("$3", "!!"),
-                                      ("$4", "??"), ("$5", "!?"), ("$6", "?!"),
+                for nag, menutext in (("$1", _("Good move")),
+                                      ("$2", _("Bad move")),
+                                      ("$3", _("Excellent move")),
+                                      ("$4", _("Very bad move")),
+                                      ("$5", _("Interesting move")),
+                                      ("$6", _("Suspicious move")),
                                       ("$7", _("Forced move"))):
-                    menuitem = Gtk.MenuItem(menutext)
+                    menuitem = Gtk.MenuItem("%s %s" % (nag2symbol(nag), menutext))
                     menuitem.connect('activate', self.symbol_menu1_activate,
                                      board, nag)
                     symbol_menu1.append(menuitem)
@@ -325,14 +329,20 @@ class Sidepanel:
                 self.menu.append(menuitem)
 
                 symbol_menu2 = Gtk.Menu()
-                for nag, menutext in (("$10", "="), ("$13", _("Unclear position")),
-                                      ("$14", "+="), ("$15", "=+"), ("$16", "±"), ("$17", "∓"),
-                                      ("$18", "+-"), ("$19", "-+"), ("$20", "+--"),
-                                      ("$21", "--+"), ("$22", _("Zugzwang")),
-                                      ("$32", _("Development adv.")), ("$36", _("Initiative")),
-                                      ("$40", _("With attack")), ("$44", _("Compensation")),
-                                      ("$132", _("Counterplay")), ("$138", _("Time pressure"))):
-                    menuitem = Gtk.MenuItem(menutext)
+                for nag, menutext in (("$10", _("Drawish")),
+                                      ("$13", _("Unclear position")),
+                                      ("$14", _("Slight advantage")),
+                                      ("$16", _("Moderate advantage")),
+                                      ("$18", _("Decisive advantage")),
+                                      ("$20", _("Crushing advantage")),
+                                      ("$22", _("Zugzwang")),
+                                      ("$32", _("Development advantage")),
+                                      ("$36", _("Initiative")),
+                                      ("$40", _("With attack")),
+                                      ("$44", _("Compensation")),
+                                      ("$132", _("Counterplay")),
+                                      ("$138", _("Time pressure"))):
+                    menuitem = Gtk.MenuItem("%s %s" % (nag2symbol(nag), menutext))
                     menuitem.connect('activate', self.symbol_menu2_activate,
                                      board, nag)
                     symbol_menu2.append(menuitem)
@@ -341,8 +351,24 @@ class Sidepanel:
                 menuitem.set_submenu(symbol_menu2)
                 self.menu.append(menuitem)
 
-                menuitem = Gtk.MenuItem(_("Remove symbols"))
+                self.menu.append(Gtk.SeparatorMenuItem())
+
+                removals_menu = Gtk.Menu()
+
+                menuitem = Gtk.MenuItem(_("Comment"))
+                menuitem.connect('activate', self.delete_comment, board, position)
+                removals_menu.append(menuitem)
+
+                menuitem = Gtk.MenuItem(_("Symbols"))
                 menuitem.connect('activate', self.remove_symbols, board)
+                removals_menu.append(menuitem)
+
+                menuitem = Gtk.MenuItem(_("All the evaluations"))
+                menuitem.connect('activate', self.reset_evaluations)
+                removals_menu.append(menuitem)
+
+                menuitem = Gtk.MenuItem(_("Remove"))
+                menuitem.set_submenu(removals_menu)
                 self.menu.append(menuitem)
 
                 self.menu.show_all()
@@ -350,14 +376,23 @@ class Sidepanel:
                                 event.time)
         return True
 
-    def copy_pgn(self, widget):
-        self.gamewidget.copy_pgn()
-
     def edit_comment(self, widget=None, board=None, index=0):
-        dialog = Gtk.Dialog(
-            _("Edit comment"), None, Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT, (
-                Gtk.STOCK_CANCEL, Gtk.ResponseType.REJECT, Gtk.STOCK_OK,
-                Gtk.ResponseType.ACCEPT))
+        creation = True
+        if not board.children:
+            board.children.append("")
+        elif not isinstance(board.children[index], str):
+            board.children.insert(index, "")
+        else:
+            creation = False
+
+        buttons_list = () if creation else (Gtk.STOCK_CLEAR, Gtk.ResponseType.REJECT)
+        buttons_list = buttons_list + (Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL,
+                                       Gtk.STOCK_OK, Gtk.ResponseType.ACCEPT)
+
+        dialog = Gtk.Dialog(_("Add comment") if creation else _("Edit comment"),
+                            None,
+                            Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,
+                            buttons_list)
 
         textedit = Gtk.TextView()
         textedit.set_editable(True)
@@ -365,10 +400,6 @@ class Sidepanel:
         textedit.set_wrap_mode(Gtk.WrapMode.WORD)
 
         textbuffer = textedit.get_buffer()
-        if not board.children:
-            board.children.append("")
-        elif not isinstance(board.children[index], str):
-            board.children.insert(index, "")
         textbuffer.set_text(board.children[index])
 
         sw = Gtk.ScrolledWindow()
@@ -380,19 +411,31 @@ class Sidepanel:
         dialog.show_all()
 
         response = dialog.run()
-        if response == Gtk.ResponseType.ACCEPT:
-            dialog.destroy()
-            (iter_first, iter_last) = textbuffer.get_bounds()
-            comment = textbuffer.get_text(iter_first, iter_last, False)
-            if board.children[index] != comment:
-                if comment:
-                    board.children[index] = comment
-                else:
-                    del board.children[index]
+        dialog.destroy()
+
+        (iter_first, iter_last) = textbuffer.get_bounds()
+        comment = textbuffer.get_text(iter_first, iter_last, False)
+        update = response in [Gtk.ResponseType.REJECT, Gtk.ResponseType.ACCEPT]
+        drop = (response == Gtk.ResponseType.REJECT) or (creation and not update) or (update and len(comment) == 0)
+        if drop:
+            if not creation:
                 self.gamemodel.needsSave = True
-                self.update()
+            del board.children[index]
         else:
-            dialog.destroy()
+            if update:
+                if board.children[index] != comment:
+                    self.gamemodel.needsSave = True
+                board.children[index] = comment
+        self.update()
+
+    def delete_comment(self, widget=None, board=None, index=0):
+        if index == -1 or not board.children:
+            return
+        elif not isinstance(board.children[index], str):
+            return
+        self.gamemodel.needsSave = True
+        del board.children[index]
+        self.update()
 
     # Add move symbol menu
     def symbol_menu1_activate(self, widget, board, nag):
@@ -410,8 +453,8 @@ class Sidepanel:
     # Add evaluation symbol menu
     def symbol_menu2_activate(self, widget, board, nag):
         color = board.color
-        if color == WHITE and nag in ("$22", "$32", "$36", "$40", "$44",
-                                      "$132", "$138"):
+        if color == WHITE and nag in ("$14", "$16", "$18", "$20", "$22", "$32",
+                                      "$36", "$40", "$44", "$132", "$138"):
             nag = "$%s" % (int(nag[1:]) + 1)
 
         if len(board.nags) == 0:
@@ -435,6 +478,10 @@ class Sidepanel:
             self.update_node(board)
             self.gamemodel.needsSave = True
 
+    def reset_evaluations(self, widget):
+        self.gamemodel.scores = {}
+        self.update()
+
     def print_node(self, node):
         """ Just a debug helper """
 
@@ -567,7 +614,7 @@ class Sidepanel:
         return iter.get_offset() - start
 
     def update_node(self, board):
-        """ Called after adding/removing evaluation simbols """
+        """ Called after adding/removing evaluation symbols """
         node = None
         for n in self.nodelist:
             if n["board"] == board:
@@ -900,10 +947,6 @@ class Sidepanel:
         pos = len(self.nodelist)
         for n in self.nodelist:
             if n["board"] == board:
-                if ini_board is not None:
-                    end_iter = self.textbuffer.get_iter_at_offset(n["start"])
-                else:
-                    end_iter = self.textbuffer.get_iter_at_offset(n["end"])
                 pos = self.nodelist.index(n)
                 break
         start = end_iter.get_offset()
@@ -962,19 +1005,24 @@ class Sidepanel:
         text = ""
         time_control = gm.tags.get('TimeControl')
         if time_control:
-            if "+" in time_control:
-                mins, inc = time_control.split('+')
-                mins = int(mins) / 60
-                mins = "{:.0f}".format(mins)
-                if inc != '0':
-                    text += mins + ' mins + ' + inc + ' secs '
-                else:
-                    text += mins + ' mins '
+            if re.match("^[0-9]+\+[0-9]+$", time_control) is None:
+                text += time_control
             else:
-                text += time_control + ' '
+                mins, inc = time_control.split('+')
+                tmin = int(floor(int(mins) / 60))
+                tsec = int(mins) - 60 * tmin
+                if tmin > 0:
+                    text += str(tmin) + " " + (_("mins") if tmin > 1 else _("min"))
+                if tsec > 0:
+                    text += " " if text != "" else ""
+                    text += str(tsec) + " " + (_("secs") if tsec > 1 else _("sec"))
+                if inc != "" and inc != "0":
+                    text += " + " + inc + " " + (_("secs") if int(inc) > 1 else _("sec")) + "/" + _("move")
 
         event = gm.tags['Event']
         if event and event != "?":
+            if len(text) > 0:
+                text += ', '
             text += event
 
         site = gm.tags['Site']
@@ -1057,7 +1105,10 @@ class Sidepanel:
             else:
                 self.nodelist.remove(node)
 
-        self.textbuffer.delete(start, end)
+        if self.gamemodel.ply > 0:
+            self.textbuffer.delete(start, end)
+        else:
+            self.update()
 
     def game_changed(self, game, ply):
         board = game.getBoardAtPly(ply, variation=0).board
