@@ -12,6 +12,7 @@ from pychess.Utils.const import ARTIFICIAL, FLAG_CALL, ABORT_OFFER, LOCAL, TAKEB
 
 from pychess.Utils.logic import validate
 from pychess.Utils.lutils import lmove, lmovegen
+from pychess.Utils.lutils.lmove import ParsingError
 
 from . import preferencesDialog
 from .PromotionDialog import PromotionDialog
@@ -39,7 +40,7 @@ def play_or_add_move(view, board, move):
             # try to find this move in variations
             for i, vari in enumerate(board.board.next.children):
                 for node in vari:
-                    if type(node) != str and node.lastMove == move.move:
+                    if type(node) != str and node.lastMove == move.move and node.plyCount == board.ply + 1:
                         # replay variation move
                         view.setShownBoard(node.pieceBoard)
                         return
@@ -65,11 +66,10 @@ class BoardControl(Gtk.EventBox):
         'action': (GObject.SignalFlags.RUN_FIRST, None, (str, object))
     }
 
-    def __init__(self, gamemodel, action_menu_items, setup_position=False, game_preview=False, setup_sub_fen=False):
+    def __init__(self, gamemodel, action_menu_items, setup_position=False, game_preview=False):
         GObject.GObject.__init__(self)
         self.setup_position = setup_position
         self.game_preview = game_preview
-        self.setup_sub_fen = setup_sub_fen
         self.view = BoardView(gamemodel, setup_position=setup_position)
         self.add(self.view)
         self.variant = gamemodel.variant
@@ -340,6 +340,7 @@ class BoardControl(Gtk.EventBox):
             self.pre_arrow_from = cord
             self.view.pre_circle = cord
             self.view.redrawCanvas()
+            return
         else:
             # remove all circles and arrows
             need_redraw = False
@@ -383,6 +384,7 @@ class BoardControl(Gtk.EventBox):
             self.pre_arrow_from = None
             self.pre_arrow_to = None
             self.view.redrawCanvas()
+            return
 
         if self.game_preview:
             return
@@ -436,7 +438,7 @@ class BoardControl(Gtk.EventBox):
                 self.view.shown, self.view.shown_variation_idx)
             try:
                 move = parseAny(board, self.keybuffer)
-            except:
+            except ParsingError:
                 self.keybuffer = ""
                 return
 
