@@ -7,6 +7,7 @@ from time import time
 import cairo
 from gi.repository import GLib, Gtk, Gdk, GObject, Pango, PangoCairo
 
+from pychess.System.prefix import addDataPrefix
 from pychess.System import conf
 from pychess.gfx import Pieces
 from pychess.Utils.Cord import Cord
@@ -123,6 +124,7 @@ def matrixAround(rotated_matrix, anchor_x, anchor_y):
                              anchor_ycorner + anchor_xside)
     return matrix, invmatrix
 
+
 ANIMATION_TIME = 0.5
 
 # If this is true, the board is scaled so that everything fits inside the window
@@ -162,13 +164,19 @@ class BoardView(Gtk.DrawingArea):
             self.model.connect("game_ended", self.gameEnded),
         ]
 
+        self.board_style_name = None
+        self.board_frame_name = None
+
         self.draw_cid = self.connect("draw", self.expose)
         self.realize_cid = self.connect_after("realize", self.onRealized)
         self.notify_cids = [
+            conf.notify_add("drawGrid", self.onDrawGrid),
             conf.notify_add("showCords", self.onShowCords),
             conf.notify_add("showCaptured", self.onShowCaptured),
             conf.notify_add("faceToFace", self.onFaceToFace),
             conf.notify_add("pieceTheme", self.onSetPieceTheme),
+            conf.notify_add("board_frame", self.onBoardFrameTheme),
+            conf.notify_add("board_style", self.onBoardColourTheme),
             conf.notify_add("lightcolour", self.onBoardColourTheme),
             conf.notify_add("darkcolour", self.onBoardColourTheme),
         ]
@@ -190,7 +198,7 @@ class BoardView(Gtk.DrawingArea):
         self.padding = 0  # Set to self.pad when setcords is active
         self.square = 0, 0, self.FILES, 1  # An object global variable with the current
         # board size
-        self.pad = 0.13  # Padding applied only when setcords is active
+        self.pad = 0.06  # Padding applied only when setcords is active
 
         self._selected = None
         self._hover = None
@@ -202,16 +210,28 @@ class BoardView(Gtk.DrawingArea):
         self._bluearrow = None
 
         self._shown = self.model.ply
+
+        self.no_frame = False
         self._show_cords = False
-        self.show_cords = conf.get("showCords", False)
+        self.show_cords = conf.get("showCords", True)
+
+        self._draw_grid = False
+        self.draw_grid = conf.get("drawGrid", True)
+
         self._show_captured = False
         if self.preview:
             self.showCaptured = False
         else:
             self.showCaptured = conf.get("showCaptured", False) or \
                 self.model.variant.variant in DROP_VARIANTS
+
+        self.onBoardColourTheme()
+        self.onBoardFrameTheme()
+
         self._show_enpassant = False
+
         self.lastMove = None
+
         self.matrix = cairo.Matrix()
         self.matrix_pi = cairo.Matrix.init_rotate(pi)
         self.invmatrix = cairo.Matrix().invert()
@@ -284,7 +304,7 @@ class BoardView(Gtk.DrawingArea):
             self.shown = ply
 
             # Rotate board
-            if conf.get("autoRotate", True):
+            if conf.get("autoRotate", False):
                 if self.model.players and self.model.curplayer.__type__ == LOCAL:
                     self.rotation = self.model.boards[-1].color * pi
 
@@ -339,11 +359,17 @@ class BoardView(Gtk.DrawingArea):
             if sound != "":
                 preferencesDialog.SoundTab.playAction(sound)
 
+    def onDrawGrid(self, *args):
+        """ Checks the configuration / preferences to see if the board
+            grid should be displayed.
+        """
+        self.draw_grid = conf.get("drawGrid", True)
+
     def onShowCords(self, *args):
         """ Checks the configuration / preferences to see if the board
             co-ordinates should be displayed.
         """
-        self.show_cords = conf.get("showCords", False)
+        self.show_cords = conf.get("showCords", True)
 
     def onShowCaptured(self, *args):
         """ Check the configuration / preferences to see if
@@ -367,6 +393,36 @@ class BoardView(Gtk.DrawingArea):
         """ If the preference to display another set of board colours has been
             selected then refresh the board
         """
+        board_style = conf.get("board_style", 1)
+        self.colors_only = board_style == 0
+        if not self.colors_only:
+            # create dark and light square surfaces
+            board_style_name = preferencesDialog.board_items[board_style][1]
+            if self.board_style_name is None or self.board_style_name != board_style_name:
+                self.board_style_name = board_style_name
+                dark_png = addDataPrefix("boards/%s_d.png" % board_style_name)
+                light_png = addDataPrefix("boards/%s_l.png" % board_style_name)
+                self.dark_surface = cairo.ImageSurface.create_from_png(dark_png)
+                self.light_surface = cairo.ImageSurface.create_from_png(light_png)
+
+        self.redrawCanvas()
+
+    def onBoardFrameTheme(self, *args):
+        board_frame = conf.get("board_frame", 1)
+        self.no_frame = board_frame == 0
+        if not self.no_frame:
+            # create board frame surface
+            board_frame_name = preferencesDialog.board_items[board_frame][1]
+            if self.board_frame_name is None or self.board_frame_name != board_frame_name:
+                self.board_frame_name = board_frame_name
+                frame_png = addDataPrefix("boards/%s_d.png" % board_frame_name)
+                self.frame_surface = cairo.ImageSurface.create_from_png(frame_png)
+
+        if not self.show_cords and self.no_frame:
+            self.padding = 0.
+        else:
+            self.padding = self.pad
+
         self.redrawCanvas()
 
     ###############################
@@ -441,6 +497,10 @@ class BoardView(Gtk.DrawingArea):
         if not self.model.lowply <= shown <= self.model.variations[self.shown_variation_idx][-1].ply:
             return
 
+        self.redarrow = None
+        self.greenarrow = None
+        self.bluearrow = None
+
         # If there is only one board, we don't do any animation, but simply
         # redraw the entire board. Same if we are at first draw.
         if len(self.model.boards) == 1 or self.shown < self.model.lowply:
@@ -794,7 +854,7 @@ class BoardView(Gtk.DrawingArea):
 
     def drawCords(self, context, rectangle):
         thickness = 0.01
-        signsize = 0.04
+        signsize = 0.02
 
         if (not self.show_cords) and (not self.setup_position):
             return
@@ -807,20 +867,11 @@ class BoardView(Gtk.DrawingArea):
         thick = thickness * square
         sign_size = signsize * square
 
-        context.rectangle(xc_loc - thick * 1.5, yc_loc - thick * 1.5,
-                          square + thick * 3, square + thick * 3)
-
-        style_ctxt = self.get_style_context()
-        DARK = hexcol(style_ctxt.lookup_color("p_dark_color")[1])
-        dcolor = Gdk.RGBA()
-        dcolor.parse(conf.get("darkcolour", DARK))
-        context.set_source_rgba(dcolor.red, dcolor.green, dcolor.blue, dcolor.alpha)
-
-        context.set_line_width(thick)
-        context.set_line_join(cairo.LINE_JOIN_ROUND)
-        context.stroke()
-
         pangoScale = float(Pango.SCALE)
+        if self.no_frame:
+            context.set_source_rgb(0.0, 0.0, 0.0)
+        else:
+            context.set_source_rgb(1.0, 1.0, 1.0)
 
         def paint(inv):
             for num in range(self.RANKS):
@@ -832,13 +883,9 @@ class BoardView(Gtk.DrawingArea):
                 height = layout.get_extents()[0].height / pangoScale
 
                 # Draw left side
-                context.move_to(xc_loc - thick * 2.5 - width, side * num + yc_loc + height / 2 + thick)
+                context.move_to(xc_loc - thick - width, side * num + yc_loc + height / 2 + thick * 3)
                 PangoCairo.show_layout(context, layout)
 
-                # Draw right side
-                # context.move_to(xc_loc+square+thick*2.5, side*num+yc_loc+h/2+thick)
-                # context.show_layout(layout)
-
                 file = inv and self.FILES - num or num + 1
                 layout = self.create_pango_layout(chr(file + ord("A") - 1))
                 layout.set_font_description(
@@ -846,23 +893,56 @@ class BoardView(Gtk.DrawingArea):
 
                 width = layout.get_pixel_size()[0]
                 height = layout.get_pixel_size()[1]
-                y_attr = layout.get_extents()[1].y / pangoScale
-
-                # Draw top
-                # context.move_to(xc_loc+side*num+side/2.-width/2., yc_loc-height-thick*1.5)
-                # context.show_layout(layout)
 
                 # Draw bottom
-                context.move_to(xc_loc + side * num + side / 2. - width / 2.,
-                                yc_loc + square + thick * 1.5 + abs(y_attr))
+                context.move_to(xc_loc + side * num + side / 2 - width / 2, yc_loc + square)
                 PangoCairo.show_layout(context, layout)
 
-        matrix, invmatrix = matrixAround(self.matrix_pi, xc_loc + square / 2., yc_loc + square / 2.)
-        paint(False)
+        matrix, invmatrix = matrixAround(self.matrix_pi, xc_loc + square / 2, yc_loc + square / 2)
+        if self.rotation == 0:
+            paint(False)
+        else:
+            context.transform(matrix)
+            paint(True)
+            context.transform(invmatrix)
 
-        context.transform(matrix)
-        paint(True)
-        context.transform(invmatrix)
+        if conf.get("faceToFace", False):
+            if self.rotation == 0:
+                context.transform(matrix)
+                paint(True)
+                context.transform(invmatrix)
+            else:
+                paint(False)
+
+    def draw_image(self, context, image_surface, left, top, width, height):
+        """ Draw a scaled image on a given context. """
+
+        # calculate scale
+        image_width = image_surface.get_width()
+        image_height = image_surface.get_height()
+        width_ratio = float(width) / float(image_width)
+        height_ratio = float(height) / float(image_height)
+        scale_xy = min(width_ratio, height_ratio)
+
+        # scale image and add it
+        context.save()
+        context.translate(left, top)
+        context.scale(scale_xy, scale_xy)
+        context.set_source_surface(image_surface)
+
+        context.paint()
+        context.restore()
+
+    def draw_frame(self, context, image_surface, left, top, width, height):
+        """ Draw a repeated image pattern on a given context. """
+
+        pat = cairo.SurfacePattern(image_surface)
+        pat.set_extend(cairo.EXTEND_REPEAT)
+
+        context.rectangle(left, top, width, height)
+        context.set_source(pat)
+
+        context.fill()
 
     ###############################
     #          drawBoard          #
@@ -870,6 +950,7 @@ class BoardView(Gtk.DrawingArea):
 
     def drawBoard(self, context, r):
         xc_loc, yc_loc, square, side = self.square
+
         style_ctxt = self.get_style_context()
         LIGHT = hexcol(style_ctxt.lookup_color("p_light_color")[1])
         col = Gdk.RGBA()
@@ -885,8 +966,12 @@ class BoardView(Gtk.DrawingArea):
             for x_loc in range(self.FILES):
                 for y_loc in range(self.RANKS):
                     if x_loc % 2 + y_loc % 2 != 1:
-                        context.rectangle(xc_loc + x_loc * side, yc_loc + y_loc * side, side, side)
-            context.fill()
+                        if self.colors_only:
+                            context.rectangle(xc_loc + x_loc * side, yc_loc + y_loc * side, side, side)
+                        else:
+                            self.draw_image(context, self.light_surface, xc_loc + x_loc * side, yc_loc + y_loc * side, side, side)
+            if self.colors_only:
+                context.fill()
 
         style_ctxt = self.get_style_context()
         DARK = hexcol(style_ctxt.lookup_color("p_dark_color")[1])
@@ -911,12 +996,40 @@ class BoardView(Gtk.DrawingArea):
             for x_loc in range(self.FILES):
                 for y_loc in range(self.RANKS):
                     if x_loc % 2 + y_loc % 2 == 1:
-                        context.rectangle((xc_loc + x_loc * side),
-                                          (yc_loc + y_loc * side), side, side)
-            context.fill()
+                        if self.colors_only:
+                            context.rectangle((xc_loc + x_loc * side), (yc_loc + y_loc * side), side, side)
+                        else:
+                            self.draw_image(context, self.dark_surface, (xc_loc + x_loc * side), (yc_loc + y_loc * side), side, side)
+            if self.colors_only:
+                context.fill()
 
-        context.rectangle(xc_loc, yc_loc, self.FILES * side, self.RANKS * side)
-        context.stroke()
+        if not self.no_frame:
+            # board frame
+            delta = side / 4
+            # top
+            self.draw_frame(context, self.frame_surface, xc_loc - delta, yc_loc - delta, self.FILES * side + delta * 2, delta)
+            # bottom
+            self.draw_frame(context, self.frame_surface, xc_loc - delta, yc_loc + self.RANKS * side, self.FILES * side + delta * 2, delta)
+            # left
+            self.draw_frame(context, self.frame_surface, xc_loc - delta, yc_loc, delta, self.FILES * side)
+            # right
+            self.draw_frame(context, self.frame_surface, xc_loc + self.FILES * side, yc_loc, delta, self.FILES * side)
+
+        if self.draw_grid:
+            # grid lines between squares
+            context.set_source_rgb(0.0, 0.0, 0.0)
+            context.set_line_width(1.0)
+
+            for loc in range(self.FILES):
+                context.move_to(xc_loc + side * loc, yc_loc)
+                context.line_to(xc_loc + side * loc, yc_loc + self.FILES * side)
+                context.move_to(xc_loc, yc_loc + side * loc)
+                context.line_to(xc_loc + self.FILES * side, yc_loc + side * loc)
+
+            context.rectangle(xc_loc, yc_loc, self.FILES * side, self.RANKS * side)
+            context.stroke()
+
+        context.set_source_rgba(col.red, col.green, col.blue, col.alpha)
 
     ###############################
     #         drawPieces          #
@@ -1115,10 +1228,12 @@ class BoardView(Gtk.DrawingArea):
 
         for cord in self.circles:
             x_loc, y_loc = self.cord2Point(cord)
+            context.new_sub_path()
             context.arc(x_loc + radius, y_loc + radius, radius - 3, 0, 2 * pi)
             context.stroke()
         if self.pre_circle is not None:
             x_loc, y_loc = self.cord2Point(self.pre_circle)
+            context.new_sub_path()
             context.arc(x_loc + radius, y_loc + radius, radius - 3, 0, 2 * pi)
             context.stroke()
 
@@ -1544,8 +1659,16 @@ class BoardView(Gtk.DrawingArea):
         return self._rotation
     rotation = property(_getRotation, _setRotation)
 
+    def _setDrawGrid(self, draw_grid):
+        self._draw_grid = draw_grid
+        self.redrawCanvas()
+
+    def _getDrawGrid(self):
+        return self._draw_grid
+    draw_grid = property(_getDrawGrid, _setDrawGrid)
+
     def _setShowCords(self, show_cords):
-        if not show_cords:
+        if not show_cords and self.no_frame:
             self.padding = 0.
         else:
             self.padding = self.pad
