@@ -7,8 +7,10 @@ from gi.repository import Gtk, Gdk, GLib, GObject
 from gi.repository.GdkPixbuf import Pixbuf
 
 from pychess.System import uistuff
-from pychess.System.prefix import getEngineDataPrefix
+from pychess.System.prefix import getEngineDataPrefix, addDataPrefix
+from pychess.Utils.IconLoader import get_pixbuf
 from pychess.Players.engineNest import discoverer, is_uci, is_cecp
+from pychess.Utils.isoCountries import ISO3166_LIST
 from pychess.widgets import newGameDialog
 from pychess.widgets import mainwindow
 
@@ -24,6 +26,24 @@ VM_LIST = [
 def run(widgets):
     global firstRun
     if firstRun:
+        # Bubble sort for the translated countries
+        for i in range(len(ISO3166_LIST) - 1, 1, - 1):
+            for j in range(1, i - 1):
+                if ISO3166_LIST[i].country < ISO3166_LIST[j].country:
+                    tmp = ISO3166_LIST[i]
+                    ISO3166_LIST[i] = ISO3166_LIST[j]
+                    ISO3166_LIST[j] = tmp
+        # Display of the countries
+        items = []
+        for iso in ISO3166_LIST:
+            path = addDataPrefix("flags/%s.png" % iso.iso2)
+            if not(iso.iso2 and os.path.isfile(path)):
+                path = addDataPrefix("flags/unknown.png")
+            items.append((get_pixbuf(path), iso.country))
+        uistuff.createCombo(widgets["engine_country_combo"], name="engine_country_combo")
+        data = [(item[0], item[1]) for item in items]
+        uistuff.updateCombo(widgets["engine_country_combo"], data)
+
         EnginesDialog(widgets)
 
         def delete_event(widget, *args):
@@ -61,7 +81,7 @@ class EnginesDialog():
                                                  Gtk.CellRendererPixbuf(),
                                                  pixbuf=0))
         name_renderer = Gtk.CellRendererText()
-        name_renderer.set_property("editable", True)
+        name_renderer.set_property("editable", False)
         self.tv.append_column(Gtk.TreeViewColumn("Name",
                                                  name_renderer,
                                                  text=1))
@@ -126,7 +146,7 @@ class EnginesDialog():
             engine_names = [row[1] for row in allstore]
             new_items = []
             # don't add the very first (Human) player to engine store
-            for item in newGameDialog.playerItems[0][1:]:
+            for item in newGameDialog.allEngineItems:
                 if item[1] not in engine_names:
                     new_items.append(item)
             ts_iter = None
@@ -176,6 +196,7 @@ class EnginesDialog():
         filter = Gtk.FileFilter()
         filter.set_name(_("Executable files"))
         filter.add_mime_type("application/x-executable")
+        filter.add_mime_type("application/x-sharedlib")
         filter.add_mime_type("application/x-ms-dos-executable")
         filter.add_mime_type("application/x-msdownload")
         filter.add_pattern("*.exe")
@@ -263,26 +284,27 @@ class EnginesDialog():
                                 break
                             else:
                                 continue
-                            if not check_ok:
-                                # restore the original
-                                engine = discoverer.getEngineByName(
-                                    self.cur_engine)
-                                engine_chooser_dialog.set_filename(engine[
-                                    "command"])
-                                msg_dia = Gtk.MessageDialog(mainwindow(),
-                                                            type=Gtk.MessageType.ERROR,
-                                                            buttons=Gtk.ButtonsType.OK)
-                                msg_dia.set_markup(
-                                    _("<big><b>Unable to add %s</b></big>" %
-                                      new_engine))
-                                msg_dia.format_secondary_text(_(
-                                    "There is something wrong with this executable"))
-                                msg_dia.run()
-                                msg_dia.hide()
-                                engine_chooser_dialog.hide()
-                                self.add = False
-                                engine_chooser_dialog.hide()
-                                return
+
+                        if not check_ok:
+                            # restore the original
+                            engine = discoverer.getEngineByName(
+                                self.cur_engine)
+                            engine_chooser_dialog.set_filename(engine[
+                                "command"])
+                            msg_dia = Gtk.MessageDialog(mainwindow(),
+                                                        type=Gtk.MessageType.ERROR,
+                                                        buttons=Gtk.ButtonsType.OK)
+                            msg_dia.set_markup(
+                                _("<big><b>Unable to add %s</b></big>" %
+                                  new_engine))
+                            msg_dia.format_secondary_text(_(
+                                "There is something wrong with this executable"))
+                            msg_dia.run()
+                            msg_dia.hide()
+                            engine_chooser_dialog.hide()
+                            self.add = False
+                            engine_chooser_dialog.hide()
+                            return
 
                         binname = os.path.split(new_engine)[1]
                         for eng in discoverer.getEngines():
@@ -300,11 +322,11 @@ class EnginesDialog():
                         if vm_args is not None:
                             vm_args = vm_args.split(",")
                         # print(binname, new_engine, protocol, vm_name, vm_args)
-                        discoverer.addEngine(binname, new_engine, protocol, vm_name, vm_args)
+                        discoverer.addEngine(binname, new_engine, protocol, vm_name, vm_args, "unknown")
                         self.cur_engine = binname
                         self.add = False
                         discoverer.discover()
-                    except:
+                    except Exception:
                         msg_dia = Gtk.MessageDialog(mainwindow(), type=Gtk.MessageType.ERROR,
                                                     buttons=Gtk.ButtonsType.OK)
                         msg_dia.set_markup(_("<big><b>Unable to add %s</b></big>" %
@@ -416,6 +438,43 @@ class EnginesDialog():
         self.widgets["engine_protocol_combo"].connect("changed",
                                                       protocol_changed)
 
+        ################################################################
+        # engine country
+        ################################################################
+        def country_changed(widget):
+            if self.cur_engine is not None and not self.selection:
+                engine = discoverer.getEngineByName(self.cur_engine)
+                old_country = discoverer.getCountry(engine)
+                new_country = ISO3166_LIST[widget.get_active()].iso2
+                if old_country != new_country:
+                    engine["country"] = new_country
+                    discoverer.save()
+
+                    # Refresh the flag in the tree view
+                    path = addDataPrefix("flags/%s.png" % new_country)
+                    if not os.path.isfile(path):
+                        path = addDataPrefix("flags/unknown.png")
+                    item = self.tv.get_selection().get_selected()
+                    if item is not None:
+                        model, ts_iter = item
+                        model[ts_iter][0] = get_pixbuf(path)
+
+                        # Notify playerCombos in NewGameTasker
+                        discoverer.emit("all_engines_discovered")
+
+        self.widgets["engine_country_combo"].connect("changed", country_changed)
+
+        def country_keypressed(widget, event):
+            idx = 0
+            for iso in ISO3166_LIST:
+                if (idx != 0) and ((ord(iso.country[0].lower()) == event.keyval) or
+                                   (ord(iso.country[0].upper()) == event.keyval)):
+                    widget.set_active(idx)
+                    break
+                idx += 1
+
+        self.widgets["engine_country_combo"].connect("key-press-event", country_keypressed)
+
         ################################################################
         # engine tree
         ################################################################
@@ -450,12 +509,23 @@ class EnginesDialog():
                 dir_choice = directory if directory is not None else self.default_workdir
                 dir_chooser_dialog.set_current_folder(dir_choice)
                 self.widgets["engine_protocol_combo"].set_active(0 if engine["protocol"] == "uci" else 1)
+
+                self.widgets["engine_country_combo"].set_active(0)
+                country = discoverer.getCountry(engine)
+                idx = 0
+                for iso in ISO3166_LIST:
+                    if iso.iso2 == country:
+                        self.widgets["engine_country_combo"].set_active(idx)
+                        break
+                    idx += 1
+
                 update_options()
                 self.selection = False
 
         tree_selection = self.tv.get_selection()
         tree_selection.connect('changed', selection_changed)
         tree_selection.select_path((0, ))
+        selection_changed(tree_selection)
 
 
 class KeyValueCellRenderer(Gtk.CellRenderer):
