@@ -10,11 +10,11 @@ import pychess
 from .BoardControl import BoardControl
 from .ChessClock import ChessClock
 from .MenuItemsDict import MenuItemsDict
-from pychess.Savers import pgn, fen
+from pychess.Savers import pgn
 from pychess.System import conf
 
 from pychess.System.Log import log
-from pychess.Utils.IconLoader import load_icon
+from pychess.Utils.IconLoader import get_pixbuf
 from pychess.Utils.const import REMOTE, UNFINISHED_STATES, PAUSED, RUNNING, LOCAL, \
     WHITE, BLACK, ACTION_MENU_ITEMS, DRAW, UNDOABLE_STATES, HINT, SPY, WHITEWON, \
     MENU_ITEMS, BLACKWON, DROP, FAN_PIECES
@@ -26,37 +26,13 @@ from pychess.Utils.logic import playerHasMatingMaterial, isClaimableDraw
 from pychess.ic import get_infobarmessage_content, get_infobarmessage_content2
 from pychess.ic.FICSObjects import get_player_tooltip_text
 from pychess.ic.ICGameModel import ICGameModel
+from pychess.widgets import createImage, createAlignment, gtk_close
 from pychess.widgets.InfoBar import InfoBarNotebook, InfoBarMessage, InfoBarMessageButton
 from pychess.perspectives import perspective_manager
 
-# ###############################################################################
-# Initialize module constants, and a few worker functions                       #
-# ###############################################################################
 
-
-def createAlignment(top, right, bottom, left):
-    align = Gtk.Alignment.new(.5, .5, 1, 1)
-    align.set_property("top-padding", top)
-    align.set_property("right-padding", right)
-    align.set_property("bottom-padding", bottom)
-    align.set_property("left-padding", left)
-    return align
-
-
-def createImage(pixbuf):
-    image = Gtk.Image()
-    image.set_from_pixbuf(pixbuf)
-    return image
-
-
-light_on = load_icon(16, "stock_3d-light-on", "weather-clear")
-light_off = load_icon(16, "stock_3d-light-off", "weather-clear-night")
-gtk_close = load_icon(16, "gtk-close", "window-close")
-
-
-# ###############################################################################
-# Initialize module variables                                                  #
-# ###############################################################################
+light_on = get_pixbuf("glade/16x16/weather-clear.png")
+light_off = get_pixbuf("glade/16x16/weather-clear-night.png")
 
 widgets = None
 
@@ -111,8 +87,6 @@ class GameWidget(GObject.GObject):
             self.gamemodel.connect("players_changed", self.players_changed),
             self.gamemodel.connect("analyzer_added", self.analyzer_added),
             self.gamemodel.connect("analyzer_removed", self.analyzer_removed),
-            self.gamemodel.connect("analyzer_resumed", self.analyzer_resumed),
-            self.gamemodel.connect("analyzer_paused", self.analyzer_paused),
             self.gamemodel.connect("message_received", self.message_received),
         ]
         self.players_changed(self.gamemodel)
@@ -140,6 +114,10 @@ class GameWidget(GObject.GObject):
             self.gamemodel.gmwidg_ready.set()
 
     def _del(self):
+        if isinstance(self.gamemodel, ICGameModel):
+            if self.gamemodel.connection.offline_lecture:
+                self.gamemodel.connection.lecture_exit_event.set()
+
         for obj in self.cids:
             if obj.handler_is_connected(self.cids[obj]):
                 log.debug("GameWidget._del: disconnecting %s" % repr(obj))
@@ -185,7 +163,7 @@ class GameWidget(GObject.GObject):
                 getWidgets()[widget].set_property('sensitive', True)
 
         # Change window title
-        getWidgets()['main_window'].set_title('%s - PyChess' % self.display_text)
+        getWidgets()['main_window'].set_title(self.display_text + (" - " if self.display_text != "" else "") + "PyChess")
 
     def _update_menu_abort(self):
         if self.gamemodel.hasEnginePlayer():
@@ -380,6 +358,10 @@ class GameWidget(GObject.GObject):
 
         if gamemodel.isObservationGame() and not self.isInFront():
             self.light_on_off(True)
+
+        if not gamemodel.isPlayingICSGame():
+            self.clearMessages()
+
         return False
 
     def game_saved(self, gamemodel, uri):
@@ -430,18 +412,16 @@ class GameWidget(GObject.GObject):
             return
 
         if len(analysis) >= 1 and analysis[0] is not None:
-            movstrs, score, depth = analysis[0]
+            ply, movstrs, score, depth, nps = analysis[0]
             board = analyzer.board
             try:
                 moves = listToMoves(board, movstrs, validate=True)
             except ParsingError as e:
                 # ParsingErrors may happen when parsing "old" lines from
                 # analyzing engines, which haven't yet noticed their new tasks
-                log.debug("__parseLine: Ignored (%s) from analyzer: ParsingError%s" %
+                log.debug("GameWidget._on_analyze(): Ignored (%s) from analyzer: ParsingError%s" %
                           (' '.join(movstrs), e))
                 return
-            except:
-                return
 
             if moves and (self.gamemodel.curplayer.__type__ == LOCAL or
                [player.__type__ for player in self.gamemodel.players] == [REMOTE, REMOTE] or
@@ -478,27 +458,29 @@ class GameWidget(GObject.GObject):
 
         return False
 
-    def analyzer_resumed(self, gamemodel, analyzer, analyzer_type):
+    def show_arrow(self, analyzer, analyzer_type):
         self.menuitems[analyzer_type + "_mode"].active = True
         self._on_analyze(analyzer, analyzer.getAnalysis(), analyzer_type)
         return False
 
-    def analyzer_paused(self, gamemodel, analyzer, analyzer_type):
+    def hide_arrow(self, analyzer, analyzer_type):
         self.menuitems[analyzer_type + "_mode"].active = False
         self._set_arrow(analyzer_type, None)
         return False
 
-    def player_display_text(self, color=WHITE):
+    def player_display_text(self, color, with_elo):
+        text = ""
         if isinstance(self.gamemodel, ICGameModel):
             if self.gamemodel.ficsplayers:
-                return self.gamemodel.ficsplayers[color].name
-            else:
-                return ""
+                text = self.gamemodel.ficsplayers[color].name
         else:
             if self.gamemodel.players:
-                return repr(self.gamemodel.players[color])
-            else:
-                return ""
+                text = repr(self.gamemodel.players[color])
+        if with_elo:
+            elo = self.gamemodel.tags.get("WhiteElo" if color == WHITE else "BlackElo")
+            if elo:
+                text += " (%s)" % str(elo)
+        return text
 
     @property
     def display_text(self):
@@ -506,8 +488,8 @@ class GameWidget(GObject.GObject):
             return ""
         '''This will give you the name of the game.'''
         vs = " - "
-        t = vs.join((self.player_display_text(color=WHITE),
-                     self.player_display_text(color=BLACK)))
+        t = vs.join((self.player_display_text(WHITE, True),
+                     self.player_display_text(BLACK, True)))
         return t
 
     def players_changed(self, gamemodel):
@@ -525,8 +507,9 @@ class GameWidget(GObject.GObject):
 
         if self.gamemodel is None:
             return
-        self.player_name_labels[color].set_text(self.player_display_text(
-            color=color))
+        name = self.player_display_text(color, False)
+        self.gamemodel.tags["White" if color == WHITE else "Black"] = name
+        self.player_name_labels[color].set_text(name)
         if isinstance(self.gamemodel, ICGameModel) and \
                 player.__type__ == REMOTE:
             self.player_name_labels[color].set_tooltip_text(
@@ -647,7 +630,12 @@ class GameWidget(GObject.GObject):
         for item in ACTION_MENU_ITEMS:
             actionMenuDic[item] = widgets[item]
 
-        board = BoardControl(gamemodel, actionMenuDic)
+        if isinstance(self.gamemodel, ICGameModel) and self.gamemodel.connection.offline_lecture:
+            preview = True
+        else:
+            preview = False
+
+        board = BoardControl(gamemodel, actionMenuDic, game_preview=preview)
         boardvbox.pack_start(board, True, True, 0)
         return boardvbox, board, infobar, cclock
 
@@ -783,10 +771,12 @@ class GameWidget(GObject.GObject):
         clipboard.set_text(pgn.save(output, self.gamemodel), -1)
 
     def copy_fen(self):
-        output = StringIO()
         clipboard = Gtk.Clipboard.get(Gdk.SELECTION_CLIPBOARD)
-        clipboard.set_text(
-            fen.save(output, self.gamemodel, self.board.view.shown), -1)
+        ply = self.board.view.shown
+        variation = self.board.view.shown_variation_idx
+        fen = self.gamemodel.getBoardAtPly(ply, variation).asFen()
+        clipboard.set_text(fen, -1)
+
 
 # ###############################################################################
 # Handling of the special sidepanels-design-gamewidget used in preferences     #
